From 35d2dd5672d7cba8b517a640eca8c46df51328aa Mon Sep 17 00:00:00 2001
From: basos g <noxelia 4t gmail c0m>
Date: Wed, 24 Dec 2008 12:59:18 +0200
Subject: [PATCH] Changed snapshot naming format to be prefix-YYMMDD-HHmms.ext

Snapshot files are named after the current local date
Rev 2
---
 src/video_output/vout_intf.c |   45 +++++++++++++++++++++++++++++++++++------
 1 files changed, 38 insertions(+), 7 deletions(-)

diff --git a/src/video_output/vout_intf.c b/src/video_output/vout_intf.c
index 7b3e6c6..80b93e0 100644
--- a/src/video_output/vout_intf.c
+++ b/src/video_output/vout_intf.c
@@ -36,6 +36,7 @@
 #include <sys/stat.h>
 #include <dirent.h>                                             /* opendir() */
 #include <assert.h>
+#include <time.h>                                           /* strftime */
 
 #include <vlc_interface.h>
 #include <vlc_block.h>
@@ -757,17 +758,47 @@ int vout_Snapshot( vout_thread_t *p_vout, picture_t *p_pic )
         }
         else
         {
-            if( asprintf( &psz_filename, "%s" DIR_SEP "%s%u.%s",
+            struct tm    curtime;
+            time_t        lcurtime ;
+            lcurtime = time( NULL ) ;
+            if ( ( localtime_r( &lcurtime, &curtime ) == NULL ) )
+            {
+                msg_Warn( p_vout, "failed to get current time. Falling back to legacy snapshot naming" );
+                /* failed to get current time. Fallback to old format */
+                if( asprintf( &psz_filename, "%s" DIR_SEP "%s%u.%s",
                           val.psz_string, psz_prefix,
                           (unsigned int)(p_pic->date / 100000) & 0xFFFFFF,
                           format.psz_string ) == -1 )
-            {
-                msg_Err( p_vout, "could not create snapshot" );
-                image_HandlerDelete( p_image );
-                return VLC_EGENERIC;
+                {
+                    msg_Err( p_vout, "could not create snapshot" );
+                    image_HandlerDelete( p_image );
+                    return VLC_EGENERIC;
+                }
             }
-        }
-
+            else
+            {
+                char psz_curtime[15] ;
+                if( strftime( psz_curtime, 15, "%y%m%d-%H%M%S", &curtime ) == 0 )
+                {
+                    msg_Warn( p_vout, "snapshot date string truncated" ) ;
+                }
+                struct stat st;
+                int i_num  = 0 ;
+                do
+                {
+                    if( asprintf( &psz_filename, "%s" DIR_SEP "%s%s%1d.%s",
+                          val.psz_string, psz_prefix,
+                          psz_curtime, i_num++,
+                          format.psz_string ) == -1 )
+                    {
+                        msg_Err( p_vout, "could not create snapshot" );
+                        image_HandlerDelete( p_image );
+                        return VLC_EGENERIC;
+                    }
+                }
+                while( utf8_stat( psz_filename, &st ) == 0 ) ;
+            } //end if time() < 0
+        } //end snapshot sequential
         free( psz_prefix );
     }
     else // The user specified a full path name (including file name)
-- 
1.5.6.5

